@@ -1,7 +1,7 @@
-# ClamTk, copyright (C) 2004-2019 Dave M
+# ClamTk, copyright (C) 2004-2021 Dave M
 #
 # This file is part of ClamTk
-# (https://gitlab.com/dave_m/clamtk-gtk3/).
+# (https://gitlab.com/dave_m/clamtk/).
 #
 # ClamTk is free software; you can redistribute it and/or modify it
 # under the terms of either:
@@ -28,17 +28,17 @@ my $infobar;
 my $top_box;
 my $box;
 
-sub start_gui {
-    # Some themes don't have all the "standard" gnome icons, so
-    # clamtk will crash if they're not there.  This is a patch from
-    # Arch Linux, which may solve the issue - or at least stop dying
-    # because it's missing an icon :|
-    # https://aur.archlinux.org/packages/clamtk/
-    my $theme = Gtk3::IconTheme::get_default;
-    $theme->append_search_path( '/usr/share/icons/gnome/24x24/actions' );
-    $theme->append_search_path( '/usr/share/icons/gnome/24x24/places' );
-    $theme->append_search_path( '/usr/share/icons/gnome/24x24/mimetypes' );
+# Some themes don't have all the "standard" gnome icons, so
+# clamtk will crash if they're not there.  This is a patch from
+# Arch Linux, which may solve the issue - or at least stop dying
+# because it's missing an icon :|
+# https://aur.archlinux.org/packages/clamtk/
+my $theme = Gtk3::IconTheme::get_default;
+$theme->append_search_path( '/usr/share/icons/gnome/24x24/actions' );
+$theme->append_search_path( '/usr/share/icons/gnome/24x24/places' );
+$theme->append_search_path( '/usr/share/icons/gnome/24x24/mimetypes' );
 
+sub start_gui {
     $window = Gtk3::Window->new( 'toplevel' );
     $window->signal_connect(
         destroy => sub {
@@ -53,58 +53,38 @@ sub start_gui {
             Gtk3->main_quit;
         }
     );
-    $window->set_border_width( 5 );
+    $window->set_border_width( 3 );
     $window->set_position( 'center' );
 
     my $hb = Gtk3::HeaderBar->new;
     $window->set_titlebar( $hb );
 
-    my $images_dir = ClamTk::App->get_path( 'images' );
-    my $pixbuf
-        = Gtk3::Gdk::Pixbuf->new_from_file_at_size( "$images_dir/clamtk.png",
-        24, 24 );
-
     my $eb = Gtk3::EventBox->new;
     $window->add( $eb );
 
-    $top_box = Gtk3::Box->new( vertical, 5 );
+    $top_box = Gtk3::Box->new( vertical, 3 );
     $top_box->set_homogeneous( FALSE );
     $eb->add( $top_box );
 
-    my $image = Gtk3::Image->new;
-    $image->set_from_pixbuf( $pixbuf );
-
-    my $button = Gtk3::ToolButton->new( $image, '' );
-    $button->set_sensitive( FALSE );
-    $button->set_tooltip_text( _( 'ClamTk Virus Scanner' ) );
-    $hb->pack_start( $button );
-
     $hb->set_title( _( 'Virus Scanner' ) );
+    $hb->set_decoration_layout( 'menu,icon:minimize,close' );
+    $hb->set_show_close_button( TRUE );
 
     my $separator = Gtk3::SeparatorToolItem->new;
     $separator->set_draw( FALSE );
     $separator->set_expand( TRUE );
     $hb->pack_end( $separator );
 
-    $button = Gtk3::ToolButton->new_from_stock( 'gtk-quit' );
-    $button->set_tooltip_text( _( 'Quit' ) );
-    $button->signal_connect(
-        clicked => sub {
-            Gtk3->main_quit;
-        }
-    );
+    my $button = Gtk3::Button->new_from_icon_name( 'help-about', 2 );
+    $button->set_can_focus( FALSE );
     $hb->pack_end( $button );
-
-    $hb->pack_end( Gtk3::SeparatorToolItem->new );
-
-    $button = Gtk3::ToolButton->new_from_stock( 'gtk-about' );
     $button->set_tooltip_text( _( 'About' ) );
-    $button->signal_connect( clicked => \&about );
-    $hb->pack_end( $button );
+    $button->signal_connect( 'clicked', sub { about() } );
 
     $box = Gtk3::Box->new( vertical, 0 );
+    $box->grab_focus;
     $top_box->set_homogeneous( FALSE );
-    $box->set_border_width( 5 );
+    $box->set_border_width( 3 );
     $top_box->add( $box );
 
     $infobar = Gtk3::InfoBar->new;
@@ -172,9 +152,6 @@ sub set_infobar_mode {
     $infobar->set_message_type( $type );
     for my $c ( $infobar->get_content_area->get_children ) {
         if ( $c->isa( 'Gtk3::Label' ) ) {
-            # Remove this (?)
-            # $c->modify_font(
-            #    Pango::FontDescription->from_string( 'Monospace' ) );
             $c->set_text( $text );
         }
     }
@@ -186,8 +163,6 @@ sub set_infobar_text_remote {
     $infobar->set_message_type( $type );
     for my $c ( $infobar->get_content_area->get_children ) {
         if ( $c->isa( 'Gtk3::Label' ) ) {
-            # $c->modify_font(
-            #    Pango::FontDescription->from_string( 'Monospace' ) );
             $c->set_text( $text );
         }
     }
@@ -197,7 +172,6 @@ sub add_configuration {
     my $show_this = shift;
 
     my $label = Gtk3::Label->new;
-  # $label->modify_font( Pango::FontDescription->from_string( 'Monospace' ) );
     $label->set_markup( "<b>$show_this</b>" );
     $label->set_alignment( 0.01, 0.5 );
 
@@ -247,27 +221,28 @@ sub add_config_panels {
         },
         {   link        => _( 'Whitelist' ),
             description => _( 'View or update scanning whitelist' ),
-            image       => 'gtk-new',
+            image       => 'security-high',
             button      => FALSE,
         },
         {   link        => _( 'Network' ),
             description => _( 'Edit proxy settings' ),
-            image       => 'gtk-network',
+            image       => 'preferences-system-network',
             button      => FALSE,
         },
         {   link        => _( 'Scheduler' ),
             description => _( 'Schedule a scan or signature update' ),
-            image       => 'gtk-properties',
+            image       => 'alarm',
             button      => FALSE,
         },
     );
 
     #<<<
-    my $theme = Gtk3::IconTheme->new;
+    # my $theme = Gtk3::IconTheme->new;
     for my $item ( @data ) {
+        my $use_image = ClamTk::Icons->get_image($item->{image});
         my $iter = $liststore->append;
-        my $pix = Gtk3::IconTheme::get_default->load_icon(
-                 $item->{image}, 24, 'use-builtin'
+        my $pix = $theme->load_icon(
+            $use_image, 24, 'use-builtin'
         );
         $liststore->set( $iter,
                 0, $pix,
@@ -319,21 +294,23 @@ sub add_update_panels {
     my @data = (
         {   link        => _( 'Update' ),
             description => _( 'Update antivirus signatures' ),
-            image       => 'gtk-goto-bottom',
+            image       => 'software-update-available',
             button      => FALSE,
         },
         {   link        => _( 'Update Assistant' ),
             description => _( 'Signature update preferences' ),
-            image       => 'gtk-color-picker',
+            image       => 'system-help',
             button      => FALSE,
         },
     );
 
     #<<<
+    # my $theme = Gtk3::IconTheme->new;
     for my $item ( @data ) {
+        my $use_image = ClamTk::Icons->get_image($item->{image});
         my $iter = $liststore->append;
-        my $pix = Gtk3::IconTheme::get_default->load_icon(
-                $item->{image}, 24, 'use-builtin'
+        my $pix = $theme->load_icon(
+            $use_image, 24, 'use-builtin'
         );
         $liststore->set( $iter,
                 0, $pix,
@@ -385,21 +362,22 @@ sub add_history_panels {
     my @data = (
         {   link        => _( 'History' ),
             description => _( 'View previous scans' ),
-            image       => 'gtk-edit',
+            image       => 'view-list',
             button      => FALSE,
         },
         {   link        => _( 'Quarantine' ),
             description => _( 'Manage quarantined files' ),
-            image       => 'gtk-refresh',
+            image       => 'user-trash-full',
             button      => FALSE,
         },
     );
 
     #<<<
     for my $item ( @data ) {
+        my $use_image = ClamTk::Icons->get_image($item->{image});
         my $iter = $liststore->append;
         my $pix = Gtk3::IconTheme::get_default->load_icon(
-                $item->{image}, 24, 'use-builtin'
+            $use_image, 24, 'use-builtin'
         );
         $liststore->set( $iter,
                 0, $pix,
@@ -451,20 +429,21 @@ sub add_analysis_panels {
     my @scan_data = (
         {   link        => _( 'Scan a file' ),
             description => _( 'Scan a file' ),
-            image       => 'gtk-file',
+            image       => 'document-new',
             button      => FALSE,
         },
         {   link        => _( 'Scan a directory' ),
             description => _( 'Scan a directory' ),
-            image       => 'gtk-directory',
+            image       => 'folder-documents',
             button      => FALSE,
         },
     );
 
     for my $item ( @scan_data ) {
+        my $use_image = ClamTk::Icons->get_image($item->{image});
         my $iter = $liststore->append;
         my $pix = Gtk3::IconTheme::get_default->load_icon(
-                $item->{image}, 24, 'use-builtin'
+                $use_image, 24, 'use-builtin'
         );
         $liststore->set( $iter,
                 0, $pix,
@@ -476,15 +455,16 @@ sub add_analysis_panels {
     my @data = (
         {   link        => _( 'Analysis' ),
             description => _( "View a file's reputation" ),
-            image       => 'gtk-find',
+            image       => 'system-search',
             button      => FALSE,
         },
     );
 
     for my $item ( @data ) {
+        my $use_image = ClamTk::Icons->get_image($item->{image});
         my $iter = $liststore->append;
         my $pix = Gtk3::IconTheme::get_default->load_icon(
-                $item->{image}, 24, 'use-builtin'
+                $use_image, 24, 'use-builtin'
         );
         $liststore->set( $iter,
                 0, $pix,
@@ -501,7 +481,6 @@ sub swap_button {
     my $change_to = shift;
     if ( $change_to ) {
         $infobar->add_button( 'gtk-go-back', -5 );
-        # $infobar->signal_connect( 'response' => \&add_default_view );
         $infobar->signal_connect(
             response => sub {
                 my ( $package, $filename, $line ) = caller;
@@ -530,7 +509,7 @@ sub press {
     my ( $path, $store ) = @_;
     return unless ( $path );
 
-    my $iter = $store->get_iter( $path );
+    my $iter  = $store->get_iter( $path );
     my $value = $store->get_value( $iter, 1 );
 
     iconview_react( $value );
@@ -540,7 +519,7 @@ sub click {
     my ( $view, $path, $model ) = @_;
     $view->unselect_all;
 
-    my $iter = $model->get_iter( $path );
+    my $iter  = $model->get_iter( $path );
     my $value = $model->get_value( $iter, 1 );
 
     iconview_react( $value );
@@ -600,10 +579,11 @@ sub select_file {
         'gtk-ok'     => 'ok',
     );
     $dialog->set_select_multiple( FALSE );
-    if ( ClamTk::Prefs->get_preference( 'ScanHidden' ) ) {
-        $dialog->set_show_hidden( TRUE );
-    }
     $dialog->set_position( 'center-on-parent' );
+
+    # FALSE until there is an option to change it
+    $dialog->set_show_hidden( FALSE );
+
     if ( 'ok' eq $dialog->run ) {
         $window->queue_draw;
         Gtk3::main_iteration while Gtk3::events_pending;
@@ -630,7 +610,8 @@ sub select_file {
 
 sub select_directory {
     my $directory = '';
-    my $dialog    = Gtk3::FileChooserDialog->new(
+
+    my $dialog = Gtk3::FileChooserDialog->new(
         _( 'Select a directory' ), $window,
         'select-folder',
         'gtk-cancel' => 'cancel',
@@ -638,9 +619,8 @@ sub select_directory {
     );
     $dialog->set_position( 'center-on-parent' );
     $dialog->set_current_folder( ClamTk::App->get_path( 'directory' ) );
-    if ( ClamTk::Prefs->get_preference( 'ScanHidden' ) ) {
-        $dialog->set_show_hidden( TRUE );
-    }
+    $dialog->set_show_hidden( FALSE );
+
     if ( 'ok' eq $dialog->run ) {
         $directory = $dialog->get_filename;
         Gtk3::main_iteration while Gtk3::events_pending;
@@ -719,8 +699,6 @@ sub about {
         . ' b) the "Artistic License".';
     $dialog->set_wrap_license( TRUE );
     $dialog->set_position( 'mouse' );
-    # $dialog->modify_font(
-    #    Pango::FontDescription->from_string( 'Monospace' ) );
 
     my $images_dir = ClamTk::App->get_path( 'images' );
     my $icon       = "$images_dir/clamtk.png";
@@ -734,7 +712,7 @@ sub about {
     $dialog->set_logo( $pixbuf );
     $dialog->set_translator_credits(
         'Please see the credits.md for full listing' );
-    $dialog->set_copyright( "\x{a9} Dave M 2004 - 2019" );
+    $dialog->set_copyright( "\x{a9} Dave M 2004 - 2021" );
     $dialog->set_program_name( 'ClamTk' );
     $dialog->set_authors( [ 'Dave M', 'dave.nerd@gmail.com' ] );
     $dialog->set_comments(
