@@ -1,7 +1,7 @@
-# ClamTk, copyright (C) 2004-2020 Dave M
+# ClamTk, copyright (C) 2004-2021 Dave M
 #
 # This file is part of ClamTk
-# (https://gitlab.com/dave_m/clamtk-gtk3/).
+# (https://gitlab.com/dave_m/clamtk/).
 #
 # ClamTk is free software; you can redistribute it and/or modify it
 # under the terms of either:
@@ -108,13 +108,13 @@ sub show_window {
         $text = _( 'Check for updates' );
         $infobar->add_button( $text, -5 );
 
-        #<<<
         $infobar->signal_connect(
             response => sub {
-                    update_signatures();
+                Gtk3::main_iteration while Gtk3::events_pending;
+                update_signatures();
+                Gtk3::main_iteration while Gtk3::events_pending;
             }
         );
-        #>>>
     }
 
     $box->pack_start( Gtk3::VBox->new, TRUE, TRUE, 5 );
@@ -129,7 +129,7 @@ sub show_window {
 }
 
 sub get_remote_TK_version {
-    my $url = 'https://bitbucket.org/davem_/clamtk-gtk3/raw/master/latest6';
+    my $url = 'https://raw.githubusercontent.com/dave-theunsub/clamtk/master/latest';
 
     $ENV{ HTTPS_DEBUG } = 1;
 
@@ -140,8 +140,10 @@ sub get_remote_TK_version {
     if ( $response->is_success ) {
         my $content = $response->content;
         chomp( $content );
+        warn "remote tk version = >$content<\n";
         return $content;
     } else {
+        warn "failed remote tk check >", $response->status_line, "<\n";
         return '';
     }
 
@@ -170,16 +172,18 @@ sub update_signatures {
     my $update;
     my $update_sig_pid;
     eval {
-        local $SIG{ ALRM }
-            = sub { die "failed updating signatures (timeout)\n" };
+        local $SIG{ ALRM } = sub {
+            die "failed updating signatures (timeout)\n";
+        };
         alarm 100;
 
         $update_sig_pid = open( $update, '-|', "$freshclam --stdout" );
-        defined( $update_sig_pid ) or do {
+        defined( $update_sig_pid )
+            or do {
             set_infobar_text( 'error',
                 _( 'Error updating: try again later' ) );
             return 0;
-        };
+            };
         alarm 0;
     };
     if ( $@ && $@ eq "failed\n" ) {
@@ -193,13 +197,42 @@ sub update_signatures {
     # We can't just print stuff out; that's bad for non-English
     # speaking users. So, we'll grab the first couple words
     # and try to sum it up.
+    #
+    # logg("!Database update process failed: %s (%d)\n"
+    # Downloading database patch # 25961..
 
     while ( defined( my $line = <$update> ) ) {
         Gtk3::main_iteration while Gtk3::events_pending;
         $pb->set_text( _( 'Downloading...' ) );
         chomp( $line );
 
-        if ( $line =~ /^Downloading daily-(\d+)/ ) {
+        if ( $line =~ /failed/ ) {
+            # Print these out to terminal window for now
+            warn $line, "\n";
+
+        } elsif ( $line =~ /Database test passed./ ) {
+            warn "Database test passed.\n";
+
+        } elsif ( $line =~ /^Downloading daily-(\d+).*?$/ ) {
+            # This one should probably be removed;
+            # was probably changed to the next elsif
+            my $new_daily = $1;
+
+            $liststore->set( $iter_hash, 0, _( 'Antivirus signatures' ),
+                1, $new_daily, );
+
+        } elsif ( $line
+            =~ q#^Retrieving https://database.clamav.net/daily-(\d+).cdiff# )
+        {
+            my $new_daily = $1;
+
+            $liststore->set( $iter_hash, 0, _( 'Antivirus signatures' ),
+                1, $new_daily, );
+
+        } elsif ( $line =~ /^Testing database/ ) {
+            $pb->set_text( _( 'Testing database' ) );
+
+        } elsif ( $line =~ /^Downloading database patch # (\d+).*?$/ ) {
             my $new_daily = $1;
 
             $liststore->set( $iter_hash, 0, _( 'Antivirus signatures' ),
@@ -207,10 +240,20 @@ sub update_signatures {
 
         } elsif ( $line =~ /Database updated/ ) {
             $pb->set_fraction( 1.0 );
+
+        } elsif (
+            # bytecode appears to be last
+            $line =~ /.*?bytecode.*?$/ && ( $line =~ /.*?up-to-date\.$/
+                || $line =~ /.*?up to date .*?/
+                || $line =~ /.*?updated\.$/ )
+            )
+        {
+            $pb->set_fraction( 1.0 );
         } else {
             # warn "skipping line: >$line<\n";
             next;
         }
+        Gtk3::main_iteration while Gtk3::events_pending;
     }
     # Get local information. It would probably be okay to just
     # keep the same number we saw during the update, but this
@@ -226,8 +269,8 @@ sub update_signatures {
     # Update infobar type and text; remove button
     set_infobar_text( 'info', _( 'Complete' ) );
     ClamTk::GUI::set_infobar_mode( 'info', '' );
-    # $pb->hide;
-    # destroy_button();
+    $pb->hide;
+    destroy_button();
 
     return TRUE;
 }
@@ -242,6 +285,8 @@ sub get_freshclam_path {
         $command
             .= " --datadir=$paths->{db} --log=$paths->{db}/freshclam.log";
     }
+    # Add verbosity
+    $command .= " --verbose";
 
     # Did the user set the proxy option?
     if ( ClamTk::Prefs->get_preference( 'HTTPProxy' ) ) {
@@ -314,7 +359,8 @@ sub add_ua_proxy {
                         if ( /HTTPProxyServer\s+(.*?)$/ ) {
                             $url = $1;
                         }
-                        last if ( !$url );
+                        last
+                            if ( !$url );
                         if ( /HTTPProxyPort\s+(\d+)$/ ) {
                             $port = $1;
                         }
